@@ -23,6 +23,8 @@ from filelock import FileLock
 from . import aws_lib
 from tipset.libs import minilog,rmt_ssh
 from functools import wraps
+from . import resource_class
+from jinja2 import Template, FileSystemLoader, Environment, PackageLoader, select_autoescape
 
 def wait_for(ret=None, not_ret=None, ck_ret=False, ck_not_ret=False, timeout=60, interval=1, log=None):
     '''
@@ -143,7 +145,7 @@ def save_resource(logfile, ami_id=None, region=None, arch=None, instance_types_l
                 if region is not None and arch is not None:
                     log.info("update region info {} which arch {} matched".format(region, arch))
                     for ami in sums:
-                        if region in ami['region'] and arch in ami["name"]:
+                        if region in ami['region'] and arch in ami['release']['arch']:
                             if instance_type is not None:
                                 ami['instance_type'] = instance_type
                             if instance_types_list is not None:
@@ -169,60 +171,9 @@ def write_html(sumlog, region_missed=None, region_uploaded=None):
     """
     logfile = sumlog
     logdir = os.path.dirname(logfile)
+    sumlog_html = logdir + '/sum.html'
+    result_tmp = resource_class.Result()
 
-    html_header = '''
-<!DOCTYPE html>
-<html lang="en">
-<head>
-  <title>AMI-VAL Test Report</title>
-  <meta charset="utf-8">
-  <meta name="viewport" content="width=device-width, initial-scale=1">
-  <link rel="stylesheet" href="https://maxcdn.bootstrapcdn.com/bootstrap/4.5.2/css/bootstrap.min.css">
-  <script src="https://ajax.googleapis.com/ajax/libs/jquery/3.5.1/jquery.min.js"></script>
-  <script src="https://cdnjs.cloudflare.com/ajax/libs/popper.js/1.16.0/umd/popper.min.js"></script>
-  <script src="https://maxcdn.bootstrapcdn.com/bootstrap/4.5.2/js/bootstrap.min.js"></script>
-  <script src="https://cdn.datatables.net/1.10.23/js/jquery.dataTables.min.js"></script>
-  <script src="https://cdn.datatables.net/1.10.23/js/dataTables.bootstrap4.min.js"></script>
-  <link rel="stylesheet" href="https://cdnjs.cloudflare.com/ajax/libs/twitter-bootstrap/4.5.2/css/bootstrap.css">
-  <link rel="stylesheet" href="https://cdn.datatables.net/1.10.23/css/dataTables.bootstrap4.min.css">
-</head>
-<body>
-
-<div class="container-fluid">
-  <h2>AMI-VAL Test Report</h2>
-  <p>This report is generated by <a href='https://pypi.org/project/ami-val/'>ami-val</a> for displaying RHEL AMIs validation result.</p>   
-  <hr class="solid">       
-    '''
-    table_header = '''
-     <table id="result" class="table table-hover table-bordered">
-    <thead>
-     <tr>
-        <th>AMI</th>
-        <th>Region</th>
-        <th>Name</th>
-        <th>CaseName</th>
-        <th>Result</th>
-        <th>Error</th>
-        <th>Debug</th>
-    </tr></thead>
-    <tbody>
-    '''
-    html_tail = '''
-    </tbody>
-  </table>
-</div>
-
-</body>
-</html>
-<script>
-$(document).ready(function() {
-  $('#result').DataTable();
-});
-</script>
-    '''
-    with open(logdir + '/sum.html', 'a+') as fh:
-        fh.write(html_header)
-    summary = {'total':0, 'pass':0, 'fail':0, 'skip':0,'error':0}
     with open(logfile, 'r') as fh:
         sums = json.load(fh)
         for ami in sums:
@@ -232,32 +183,15 @@ $(document).ready(function() {
             for r in ami['result']:
                 result = r['result']
                 if 'PASS' in result:
-                    summary['pass'] += 1
+                    result_tmp.case_pass += 1
                 elif 'FAIL' in result:
-                    summary['fail'] += 1
+                    result_tmp.case_fail += 1
                 elif 'SKIP' in result:
-                    summary['skip'] += 1
+                    result_tmp.case_skip += 1
                 elif 'ERROR' in result:
-                    summary['error'] += 1
+                    result_tmp.case_error += 1
                 else:
-                    summary['fail'] += 1
-                summary['total'] += 1
-    pass_rate = (summary['pass'])/(summary['total'] - summary['skip'])*100
-    summary = """
-        <!-- Table -->
-        <table class="table table-bordered">
-            <tr>
-            <td>Summary</td><td>Total:<b>{}</b>, PASS:<b class="text-success">{}</b>, FAIL:<b class="text-danger">{}</b>, SKIP:<b class="text-warning">{}</b>, ERROR:<b class="text-danger">{}</b> - success rate of <b>{}</b>% (excluding SKIP and CANCEL)</tr>
-            <tr>
-            <td>Regions Uploaded</td><td>{}</td></tr>
-            <tr>
-            <td>Regions Missed</td><td>{}</td></tr>
-        </table>
-    """.format(summary['total'],summary['pass'],summary['fail'],summary['skip'],summary['error'],format(pass_rate,'0.2f'),region_uploaded, region_missed)
-    with open(logdir + '/sum.html', 'a+') as fh:
-        fh.write(summary)
-    with open(logdir + '/sum.html', 'a+') as fh:
-        fh.write(table_header)
+                    result_tmp.case_fail += 1
     with open(logfile, 'r') as fh:
         sums = json.load(fh)
         for ami in sums:
@@ -269,13 +203,14 @@ $(document).ready(function() {
                 result = r['result']
                 error = r['error']
                 debuglog = 'debug/' + ami_id + '_' + casename + '.log'
-                item = "<tr><td>{}</td><td>{}</td><td>{}</td><td>{}</td><td>{}</td><td>{}</td> \
-                    <td><a href='{}'>debug</a></td></tr>".format(ami_id, region, name,
-                    casename, result, error, debuglog)
-                with open(logdir + '/sum.html', 'a+') as fh:
-                    fh.write(item)
-    with open(logdir + '/sum.html', 'a+') as fh:
-        fh.write(html_tail)
+                result_tmp.cases.append((ami_id, region, name, casename, result, error, debuglog))
+    file_loader = PackageLoader('ami_val','templates')
+    env = Environment(loader=file_loader)
+    template = env.get_template('sum.html')
+    output = template.render(result=result_tmp, region_missed=region_missed, region_uploaded=region_uploaded)
+    with open(sumlog_html, 'w+') as fh:
+        print(output, file=fh)
+    print("HTML summary:{}".format(sumlog_html))
             
 
 def prepare_dir(args):
@@ -484,9 +419,9 @@ def run_cmd(test_instance,
     if expect_kw is not None:
         for key_word in expect_kw.split(','):
             if output.count('\n') > 5:
-                find_list = re.findall('.*{}.*\n'.format(key_word), output)
+                find_list = re.findall('.*{}.*\n'.format(re.escape(key_word)), output)
             else:
-                find_list = re.findall('.*{}.*'.format(key_word), output)
+                find_list = re.findall('.*{}.*'.format(re.escape(key_word)), output)
             if len(find_list) > 0:
                 test_instance.log.info('expcted "{}" found in "{}"'.format(key_word, ''.join(find_list)))
             else:
@@ -497,9 +432,9 @@ def run_cmd(test_instance,
     if expect_not_kw is not None:
         for key_word in expect_not_kw.split(','):
             if output.count('\n') > 5:
-                find_list = re.findall('.*{}.*\n'.format(key_word), output)
+                find_list = re.findall('.*{}.*\n'.format(re.escape(key_word)), output)
             else:
-                find_list = re.findall('.*{}.*'.format(key_word), output)
+                find_list = re.findall('.*{}.*'.format(re.escape(key_word)), output)
             if len(find_list) == 0:
                 test_instance.log.info('Unexpcted "{}" not found in output'.format(key_word))
             else:
@@ -689,7 +624,7 @@ def is_cmd_exist(test_instance, cmd=None, is_install=True, cancel_case=False):
     pkg_find = "sudo yum provides %s" % cmd
     output = run_cmd(test_instance, pkg_find, expect_ret=0)
     for i in [arch, 'noarch']:
-        pkg_list = re.findall(".*%s" % i, output)
+        pkg_list = re.findall("[^\s]+%s" % i, output)
         if len(pkg_list) > 0:
             break
     if len(pkg_list) == 0:
@@ -944,3 +879,25 @@ new one", same_rate)
             no_fail = False
 
     return no_fail
+
+def get_product_id(test_instance):
+    check_cmd = "sudo cat /etc/redhat-release"
+    output = run_cmd(test_instance,check_cmd, expect_ret=0, msg='check release name')
+    product_id = re.findall('[\d.]{2,3}', output)[0]
+    test_instance.log.info("Get product id: {}".format(product_id))
+    return product_id
+
+def is_fedora(test_instance):
+    aminame = test_instance.info['name']
+    if 'Fedora' in aminame:
+        test_instance.log.info('Fedora AMI found from name:{}'.format(aminame))
+    else:
+        return False
+    if test_instance.vm is not None:
+        check_cmd = "sudo cat /etc/redhat-release"
+        output = run_cmd(test_instance,check_cmd, expect_ret=0, msg='check release name')
+        if 'Fedora' in output:
+            test_instance.log.info('Fedora system found inside AMI {}'.format(aminame))
+        else:
+            return False
+    return True
